#################################################################
#  MultiChannelSplit
#  
#  @author simon jokuschies
#  @email info@leafpictures.de
#  @version 1.0
#
#  description:
#  the script splits a multichannel exr into single layers
#  and autocrops them automatically.
#
#################################################################

import nuke;

def getUniqueChannelLayerList(readNode):
    #function that returns unique channel layers
    rawChannelList = readNode.channels()    
    channelLayerList = []
    for channel in rawChannelList:
        channelLayer = channel.split(".")
        channelLayerList .append(channelLayer[0])
    return list(set(channelLayerList))


def MultiChannelSplit():
    selectedNodes = nuke.selectedNodes()
    lenSelectedNodes= len(selectedNodes)
    shuffles=[]

    if len(selectedNodes)>0:
        
        #main procedure
        #create shuffle, shuffle channel in, curvetool crop, create cropnode and paste that information in, delete crop node
        for readNode in selectedNodes:
            if readNode.Class()=="Read":
                uniqueLayers = getUniqueChannelLayerList(readNode)
        
                for channelLayer in uniqueLayers:
                    shuffleNode = nuke.nodes.Shuffle(name="Shuffle_"+channelLayer)        
                    shuffles.append(shuffleNode.name())
                    shuffleNode.knob("in").setValue(channelLayer)
                    shuffleNode.setInput(0,readNode)
                    
                    curveNode = nuke.nodes.CurveTool(name="Autocrop_"+channelLayer, inputs = [shuffleNode], operation="Auto Crop")
                    curveNode.knob("ROI").setValue([0,0,readNode.width(),readNode.height()])
                    nuke.execute(curveNode, readNode.knob("first").value(), readNode.knob("last").value())
                    cropNode = nuke.nodes.Crop(name="Crop_"+channelLayer, inputs = [curveNode])
                    cropNode.knob("box").copyAnimations(curveNode.knob("autocropdata").animations())

                    nuke.delete(curveNode)                    
                    cropNode.knob("postage_stamp").setValue(True)                     
            else:
                nuke.message("No read node selected")
        
        #hide all created shuffle inputs
        for shuffleNode in shuffles:
            temp = nuke.toNode(shuffleNode)
            temp.knob("hide_input").setValue(True)
        
        nuke.message("Finished shuffling channels and autocropping them")
    else:
            nuke.message("Please select a read node first")